const system = require("../../../system");
const ServiceBase = require("../../sve.base")
class RoleService extends ServiceBase {
  constructor() {
    super("role", ServiceBase.getDaoName(RoleService));
  }

  /**
   * role  添加 
   * @param {*} params 
   */
  async apiAddRole(params) {
    try {
      return await this.addRole(params);
    } catch (error) {
      return system.getResult(null, `系统错误 错误信息 ${error}`);
    }
  }

  /**
   * role  更新 
   * @param {*} params 
   */
  async apiUpdRole(params) {
    try {
      return await this.updateRole(params);
    } catch (error) {
      return system.getResult(null, `系统错误 错误信息 ${error}`);
    }
  }

  /**
   * role  删除 
   * @param {*} params 
   */
  async apiDelRole(params) {
    try {
      return await this.delRole(params);
    } catch (error) {
      return system.getResult(null, `系统错误 错误信息 ${error}`);
    }
  }


  /**
   * role 查询列表 
   * @param {*} params 
   */
  async apiListRole(params) {
    try {
      return await this.listRole(params);
    } catch (error) {
      return system.getResult(null, `系统错误 错误信息 ${error}`);
    }
  }




  /***************************************************************** */


  /**
   * 添加
   * @param {T} params 
   */
  async addRole(params) {
    params.code = this.trim(params.code);
    params.name = this.trim(params.name);
    params.saas_id = Number(params.saas_id || 0);
    try {
      let res = await this.create(params);
      console.log(`saas 信息插入 ： ${JSON.stringify(res)}`);
      return system.getResult(res);
    } catch (error) {
      return system.getResult(-1, `系统错误 错误信息 ${error}`);
    }
  }

  /**
   * 更新
   * @param {T} params 
   */
  async updateRole(params) {
    if (params.id) {
      params.id = Number(this.trim(params.id));
    }
    let _role = await this.findById(this.trim(params.id));
    if (!_role) {
      return system.getResult(-1, `参数错误 角色不存在`);
    }
    if (params.code) {
      _role.code = this.trim(params.code);
    }
    if (params.name) {
      _role.name = this.trim(params.name);
    }
    if (params.saas_id) {
      _role.name = Number(params.saas_id);
    }
    try {
      let res = await _role.save();
      console.log(`saas 信息插入 ： ${JSON.stringify(res)}`);
      return system.getResult(res);
    } catch (error) {
      return system.getResult(-1, `系统错误 错误信息 ${error}`);
    }
  }

  /**
   * 删除角色
   * @param {*} params 
   */
  async delRole(params) {
    try {
      //检查是否存在此记录
      if (!params.id) {
        return system.getResult(-1, `参数错误 ID不能为空`);
      }
      params.id = this.trim(params.id);
      let _role = await this.findById(params.id);
      if (!_role) {
        return system.getResult(-1, `角色不存在`);
      }
      //检查该角色是否有用户使用
      let users = await this.dao.findUserByRoleId(params);
      if (!users || users.length != 0) {
        return system.getResult(-1, `角色不能删除`);
      }
      //删除并删除对应表
      let res = await _role.destroy();
      return system.getResult(res);
    } catch (error) {
      return system.getResult(-1, `系统错误 错误信息${error}`);
    }
  }

  /**
   * 查询列表
   * @param {*} params 
   */
  async listRole(params) {
    let where = {};
    let pageIndex = params.pageIndex || 1;
    let pageSize = params.pageSize || 10;
    if (params.code) {
      where.code = this.trim(params.code);
    }
    if (params.name) {
      where.name = this.trim(params.name);
    }
    if (params.hasOwnProperty("saas_id")) {
      where.saas_id = Number(params.saas_id);
    }
    try {
      let roleList = await this.getPageList(pageIndex, pageSize, where);
      return system.getResult(roleList);
    } catch (error) {
      return system.getResult(-1, `系统错误 错误信息 ${error}`);
    }
  }

}
module.exports = RoleService;
